from django.apps import AppConfig


class RequestLoggerConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'request_track'
